flag_descriptions = {
    "active": "Makes active connections to target systems",
    "affiliates": "Discovers affiliated hostnames/domains",
    "aggressive": "Generates a large amount of network traffic",
    "baddns": "Runs all modules from the DNS auditing tool BadDNS",
    "cloud-enum": "Enumerates cloud resources",
    "code-enum": "Find public code repositories and search them for secrets etc.",
    "deadly": "Highly aggressive",
    "email-enum": "Enumerates email addresses",
    "iis-shortnames": "Scans for IIS Shortname vulnerability",
    "passive": "Never connects to target systems",
    "portscan": "Discovers open ports",
    "report": "Generates a report at the end of the scan",
    "safe": "Non-intrusive, safe to run",
    "service-enum": "Identifies protocols running on open ports",
    "slow": "May take a long time to complete",
    "social-enum": "Enumerates social media",
    "subdomain-enum": "Enumerates subdomains",
    "subdomain-hijack": "Detects hijackable subdomains",
    "web-basic": "Basic, non-intrusive web scan functionality",
    "web-paramminer": "Discovers HTTP parameters through brute-force",
    "web-screenshots": "Takes screenshots of web pages",
    "web-thorough": "More advanced web scanning functionality",
}
